@@ -4,29 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class AnalysisStatus
-  {
-    NOT_SET,
-    running,
-    succeeded,
-    failed
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class AnalysisStatus { NOT_SET, running, succeeded, failed };
 
-namespace AnalysisStatusMapper
-{
+namespace AnalysisStatusMapper {
 AWS_EC2_API AnalysisStatus GetAnalysisStatusForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForAnalysisStatus(AnalysisStatus value);
-} // namespace AnalysisStatusMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace AnalysisStatusMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
